@@ -5,10 +5,10 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
-func decodeNullFn(sms ...scalar.Mapper) (DecodeFn, error) {
+func decodeNullFn(sms ...scalar.AnyMapper) (DecodeFn, error) {
 	// null is written as zero bytes.
 	return func(name string, d *decode.D) any {
-		d.FieldValueNil(name, sms...)
+		d.FieldValueAny(name, nil, sms...)
 		return nil
 	}, nil
 }
