@@ -25,17 +25,19 @@ func decodeBits(unit int) func(d *decode.D) any {
 }
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:               format.BITS,
-		Description:        "Raw bits",
-		DecodeFn:           decodeBits(1),
-		SkipDecodeFunction: true, // skip add bits and frombits function
-	})
-	interp.RegisterFormat(decode.Format{
-		Name:               format.BYTES,
-		Description:        "Raw bytes",
-		DecodeFn:           decodeBits(8),
-		SkipDecodeFunction: true, // skip add bytes and frombytes function
-	})
+	interp.RegisterFormat(
+		format.Bits,
+		&decode.Format{
+			Description:        "Raw bits",
+			DecodeFn:           decodeBits(1),
+			SkipDecodeFunction: true, // skip add bits and frombits function
+		})
+	interp.RegisterFormat(
+		format.Bytes,
+		&decode.Format{
+			Description:        "Raw bytes",
+			DecodeFn:           decodeBits(8),
+			SkipDecodeFunction: true, // skip add bytes and frombytes function
+		})
 	interp.RegisterFS(bitsFS)
 }
