@@ -16,48 +16,49 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
-var flacMetadatablocksFormat decode.Group
-var flacFrameFormat decode.Group
+var flacMetadatablocksGroup decode.Group
+var flacFrameGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.FLAC,
-		Description: "Free Lossless Audio Codec file",
-		Groups:      []string{format.PROBE},
-		DecodeFn:    flacDecode,
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.FLAC_METADATABLOCKS}, Group: &flacMetadatablocksFormat},
-			{Names: []string{format.FLAC_FRAME}, Group: &flacFrameFormat},
-		},
-	})
+	interp.RegisterFormat(
+		format.FLAC,
+		&decode.Format{
+			Description: "Free Lossless Audio Codec file",
+			Groups:      []*decode.Group{format.Probe},
+			DecodeFn:    flacDecode,
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.FLAC_Metadatablocks}, Out: &flacMetadatablocksGroup},
+				{Groups: []*decode.Group{format.FLAC_Frame}, Out: &flacFrameGroup},
+			},
+		})
 }
 
 func flacDecode(d *decode.D) any {
 	d.FieldUTF8("magic", 4, d.StrAssert("fLaC"))
 
-	var streamInfo format.FlacStreamInfo
-	var flacFrameIn format.FlacFrameIn
+	var streamInfo format.FLAC_Stream_Info
+	var flacFrameIn format.FLAC_Frame_In
 	var framesNDecodedSamples uint64
 	var streamTotalSamples uint64
 	var streamDecodedSamples uint64
 
-	_, v := d.FieldFormat("metadatablocks", flacMetadatablocksFormat, nil)
-	flacMetadatablockOut, ok := v.(format.FlacMetadatablocksOut)
+	_, v := d.FieldFormat("metadatablocks", &flacMetadatablocksGroup, nil)
+	flacMetadatablockOut, ok := v.(format.FLAC_Metadatablocks_Out)
 	if !ok {
 		panic(fmt.Sprintf("expected FlacMetadatablockOut got %#+v", v))
 	}
 	if flacMetadatablockOut.HasStreamInfo {
 		streamInfo = flacMetadatablockOut.StreamInfo
 		streamTotalSamples = streamInfo.TotalSamplesInStream
-		flacFrameIn = format.FlacFrameIn{BitsPerSample: int(streamInfo.BitsPerSample)}
+		flacFrameIn = format.FLAC_Frame_In{BitsPerSample: int(streamInfo.BitsPerSample)}
 	}
 
 	md5Samples := md5.New()
 	d.FieldArray("frames", func(d *decode.D) {
 		for d.NotEnd() {
 			// flac frame might need some fields from stream info to decode
-			_, v := d.FieldFormat("frame", flacFrameFormat, flacFrameIn)
-			ffo, ok := v.(format.FlacFrameOut)
+			_, v := d.FieldFormat("frame", &flacFrameGroup, flacFrameIn)
+			ffo, ok := v.(format.FLAC_Frame_Out)
 			if !ok {
 				panic(fmt.Sprintf("expected FlacFrameOut got %#+v", v))
 			}
