@@ -15,15 +15,16 @@ import (
 var ether8023FrameInetPacketGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.ETHER8023_FRAME,
-		Description: "Ethernet 802.3 frame",
-		Groups:      []string{format.LINK_FRAME},
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.INET_PACKET}, Group: &ether8023FrameInetPacketGroup},
-		},
-		DecodeFn: decodeEthernetFrame,
-	})
+	interp.RegisterFormat(
+		format.Ether_8023_Frame,
+		&decode.Format{
+			Description: "Ethernet 802.3 frame",
+			Groups:      []*decode.Group{format.Link_Frame},
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.INET_Packet}, Out: &ether8023FrameInetPacketGroup},
+			},
+			DecodeFn: decodeEthernetFrame,
+		})
 }
 
 // TODO: move to shared?
@@ -35,7 +36,7 @@ var mapUToEtherSym = scalar.UintFn(func(s scalar.Uint) (scalar.Uint, error) {
 })
 
 func decodeEthernetFrame(d *decode.D) any {
-	var lfi format.LinkFrameIn
+	var lfi format.Link_Frame_In
 	if d.ArgAs(&lfi) {
 		if lfi.Type != format.LinkTypeETHERNET {
 			d.Fatalf("wrong link type %d", lfi.Type)
@@ -49,8 +50,8 @@ func decodeEthernetFrame(d *decode.D) any {
 	d.FieldFormatOrRawLen(
 		"payload",
 		d.BitsLeft(),
-		ether8023FrameInetPacketGroup,
-		format.InetPacketIn{EtherType: int(etherType)},
+		&ether8023FrameInetPacketGroup,
+		format.INET_Packet_In{EtherType: int(etherType)},
 	)
 
 	return nil
