@@ -28,8 +28,8 @@ type TCPDirection struct {
 }
 
 type TCPConnection struct {
-	Client     TCPDirection
-	Server     TCPDirection
+	Client     *TCPDirection
+	Server     *TCPDirection
 	tcpState   *reassembly.TCPSimpleFSM
 	optChecker *reassembly.TCPOptionCheck
 	net        gopacket.Flow
@@ -62,9 +62,9 @@ func (t *TCPConnection) ReassembledSG(sg reassembly.ScatterGather, ac reassembly
 	var d *TCPDirection
 	switch dir {
 	case reassembly.TCPDirClientToServer:
-		d = &t.Client
+		d = t.Client
 	case reassembly.TCPDirServerToClient:
-		d = &t.Server
+		d = t.Server
 	default:
 		panic("unreachable")
 	}
@@ -115,14 +115,14 @@ func (fd *Decoder) New(net, transport gopacket.Flow, tcp *layers.TCP, ac reassem
 	}
 
 	stream := &TCPConnection{
-		Client: TCPDirection{
+		Client: &TCPDirection{
 			Endpoint: TCPEndpoint{
 				IP:   append([]byte(nil), net.Src().Raw()...),
 				Port: clientPort,
 			},
 			Buffer: &bytes.Buffer{},
 		},
-		Server: TCPDirection{
+		Server: &TCPDirection{
 			Endpoint: TCPEndpoint{
 				IP:   append([]byte(nil), net.Dst().Raw()...),
 				Port: serverPort,
