@@ -8,12 +8,13 @@ import (
 )
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.ICMPV6,
-		Description: "Internet Control Message Protocol v6",
-		Groups:      []string{format.IP_PACKET},
-		DecodeFn:    decodeICMPv6,
-	})
+	interp.RegisterFormat(
+		format.ICMPv6,
+		&decode.Format{
+			Description: "Internet Control Message Protocol v6",
+			Groups:      []*decode.Group{format.IP_Packet},
+			DecodeFn:    decodeICMPv6,
+		})
 }
 
 // based on https://en.wikipedia.org/wiki/Internet_Control_Message_Protocol_for_IPv6
@@ -78,7 +79,7 @@ var icmpv6CodeMapMap = map[uint64]scalar.UintMapDescription{
 }
 
 func decodeICMPv6(d *decode.D) any {
-	var ipi format.IPPacketIn
+	var ipi format.IP_Packet_In
 	if d.ArgAs(&ipi) && ipi.Protocol != format.IPv4ProtocolICMPv6 {
 		d.Fatalf("incorrect protocol %d", ipi.Protocol)
 	}
