@@ -15,18 +15,19 @@ import (
 var ipv4IpPacketGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.IPV4_PACKET,
-		Description: "Internet protocol v4 packet",
-		Groups: []string{
-			format.INET_PACKET,
-			format.LINK_FRAME,
-		},
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.IP_PACKET}, Group: &ipv4IpPacketGroup},
-		},
-		DecodeFn: decodeIPv4,
-	})
+	interp.RegisterFormat(
+		format.IPv4Packet,
+		&decode.Format{
+			Description: "Internet protocol v4 packet",
+			Groups: []*decode.Group{
+				format.INET_Packet,
+				format.Link_Frame,
+			},
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.IP_Packet}, Out: &ipv4IpPacketGroup},
+			},
+			DecodeFn: decodeIPv4,
+		})
 }
 
 const (
@@ -53,8 +54,8 @@ var mapUToIPv4Sym = scalar.UintFn(func(s scalar.Uint) (scalar.Uint, error) {
 })
 
 func decodeIPv4(d *decode.D) any {
-	var ipi format.InetPacketIn
-	var lfi format.LinkFrameIn
+	var ipi format.INET_Packet_In
+	var lfi format.Link_Frame_In
 	if d.ArgAs(&ipi) && ipi.EtherType != format.EtherTypeIPv4 {
 		d.Fatalf("incorrect ethertype %d", ipi.EtherType)
 	} else if d.ArgAs(&lfi) && lfi.Type != format.LinkTypeIPv4 && lfi.Type != format.LinkTypeRAW {
@@ -113,8 +114,8 @@ func decodeIPv4(d *decode.D) any {
 		d.FieldFormatOrRawLen(
 			"payload",
 			dataLen,
-			ipv4IpPacketGroup,
-			format.IPPacketIn{Protocol: int(protocol)},
+			&ipv4IpPacketGroup,
+			format.IP_Packet_In{Protocol: int(protocol)},
 		)
 	}
 
