@@ -13,19 +13,20 @@ import (
 var sllPacket2InetPacketGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.SLL2_PACKET,
-		Description: "Linux cooked capture encapsulation v2",
-		Groups:      []string{format.LINK_FRAME},
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.INET_PACKET}, Group: &sllPacket2InetPacketGroup},
-		},
-		DecodeFn: decodeSLL2,
-	})
+	interp.RegisterFormat(
+		format.SLL2_Packet,
+		&decode.Format{
+			Description: "Linux cooked capture encapsulation v2",
+			Groups:      []*decode.Group{format.Link_Frame},
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.INET_Packet}, Out: &sllPacket2InetPacketGroup},
+			},
+			DecodeFn: decodeSLL2,
+		})
 }
 
 func decodeSLL2(d *decode.D) any {
-	var lfi format.LinkFrameIn
+	var lfi format.Link_Frame_In
 	if d.ArgAs(&lfi) && lfi.Type != format.LinkTypeLINUX_SLL2 {
 		d.Fatalf("wrong link type %d", lfi.Type)
 	}
@@ -54,8 +55,8 @@ func decodeSLL2(d *decode.D) any {
 		d.FieldFormatOrRawLen(
 			"payload",
 			d.BitsLeft(),
-			sllPacket2InetPacketGroup,
-			format.InetPacketIn{EtherType: int(protcolType)},
+			&sllPacket2InetPacketGroup,
+			format.INET_Packet_In{EtherType: int(protcolType)},
 		)
 	default:
 		d.FieldRawLen("payload", d.BitsLeft())
