@@ -13,15 +13,16 @@ import (
 var sllPacketInetPacketGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.SLL_PACKET,
-		Description: "Linux cooked capture encapsulation",
-		Groups:      []string{format.LINK_FRAME},
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.INET_PACKET}, Group: &sllPacketInetPacketGroup},
-		},
-		DecodeFn: decodeSLL,
-	})
+	interp.RegisterFormat(
+		format.SLL_Packet,
+		&decode.Format{
+			Description: "Linux cooked capture encapsulation",
+			Groups:      []*decode.Group{format.Link_Frame},
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.INET_Packet}, Out: &sllPacketInetPacketGroup},
+			},
+			DecodeFn: decodeSLL,
+		})
 }
 
 var sllPacketTypeMap = scalar.UintMap{
@@ -109,7 +110,7 @@ var arpHdrTypeMAp = scalar.UintMap{
 }
 
 func decodeSLL(d *decode.D) any {
-	var lfi format.LinkFrameIn
+	var lfi format.Link_Frame_In
 	if d.ArgAs(&lfi) && lfi.Type != format.LinkTypeLINUX_SLL {
 		d.Fatalf("wrong link type %d", lfi.Type)
 	}
@@ -131,8 +132,8 @@ func decodeSLL(d *decode.D) any {
 		d.FieldFormatOrRawLen(
 			"payload",
 			d.BitsLeft(),
-			sllPacketInetPacketGroup,
-			format.InetPacketIn{EtherType: int(protcolType)},
+			&sllPacketInetPacketGroup,
+			format.INET_Packet_In{EtherType: int(protcolType)},
 		)
 	default:
 		d.FieldU16LE("protocol_type")
