@@ -20,14 +20,15 @@ import (
 var jsonFS embed.FS
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.JSON,
-		Description: "JavaScript Object Notation",
-		ProbeOrder:  format.ProbeOrderTextJSON,
-		Groups:      []string{format.PROBE},
-		DecodeFn:    decodeJSON,
-		Functions:   []string{"_todisplay"},
-	})
+	interp.RegisterFormat(
+		format.JSON,
+		&decode.Format{
+			Description: "JavaScript Object Notation",
+			ProbeOrder:  format.ProbeOrderTextJSON,
+			Groups:      []*decode.Group{format.Probe},
+			DecodeFn:    decodeJSON,
+			Functions:   []string{"_todisplay"},
+		})
 	interp.RegisterFS(jsonFS)
 	interp.RegisterFunc1("_to_json", toJSON)
 }
@@ -93,12 +94,12 @@ func makeEncoder(opts ToJSONOpts) *colorjson.Encoder {
 		Color:  false,
 		Tab:    false,
 		Indent: opts.Indent,
-		ValueFn: func(v any) any {
+		ValueFn: func(v any) (any, error) {
 			switch v := v.(type) {
 			case gojq.JQValue:
-				return v.JQValueToGoJQ()
+				return v.JQValueToGoJQ(), nil
 			default:
-				return v
+				return v, nil
 			}
 		},
 		Colors: colorjson.Colors{},
