@@ -14,16 +14,17 @@ import (
 )
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.AAC_FRAME,
-		Description: "Advanced Audio Coding frame",
-		DecodeFn:    aacDecode,
-		DefaultInArg: format.AACFrameIn{
-			ObjectType: format.MPEGAudioObjectTypeMain,
-		},
-		RootArray: true,
-		RootName:  "elements",
-	})
+	interp.RegisterFormat(
+		format.AAC_Frame,
+		&decode.Format{
+			Description: "Advanced Audio Coding frame",
+			DecodeFn:    aacDecode,
+			DefaultInArg: format.AAC_Frame_In{
+				ObjectType: format.MPEGAudioObjectTypeMain,
+			},
+			RootArray: true,
+			RootName:  "elements",
+		})
 }
 
 const (
@@ -271,7 +272,7 @@ func aacFillElement(d *decode.D) {
 }
 
 func aacDecode(d *decode.D) any {
-	var ai format.AACFrameIn
+	var ai format.AAC_Frame_In
 	d.ArgAs(&ai)
 
 	// TODO: seems tricky to know length of blocks
