@@ -1,17 +1,21 @@
 package decode
 
-type Group []Format
+type Group struct {
+	Name         string
+	Formats      []*Format
+	DefaultInArg any
+}
 
 type Dependency struct {
-	Names []string
-	Group *Group
+	Groups []*Group
+	Out    *Group
 }
 
 type Format struct {
 	Name               string
 	ProbeOrder         int // probe order is from low to hi value then by name
 	Description        string
-	Groups             []string
+	Groups             []*Group
 	DecodeFn           func(d *D) any
 	DefaultInArg       any
 	RootArray          bool
@@ -21,8 +25,10 @@ type Format struct {
 	SkipDecodeFunction bool
 }
 
-func FormatFn(d func(d *D) any) Group {
-	return Group{{
-		DecodeFn: d,
-	}}
+func FormatFn(fn func(d *D) any) *Group {
+	return &Group{
+		Formats: []*Format{
+			{DecodeFn: fn},
+		},
+	}
 }
